==> captur-ml-0.2.32.tar.gz: captur-ml-0.2.32/captur_ml_sdk/dtypes/exceptions/__init__.py <==
# ============ PubSub Exceptions ============ #
class GoogleCloudPubSubTopicDoesNotExistError(Exception):
    pass

# ============ Google Cloud Storage Exceptions ============ #
class GoogleCloudStoragePermissionError(Exception):
    pass
class GoogleCloudStorageResourceNotFoundError(Exception):
    pass
class GoogleCloudStorageBucketNotFoundError(Exception):
    pass

# ============ Google Cloud Vertex AI Endpoint Exceptions ============ #
class GoogleCloudVertexAIEndpointDoesNotExistError(Exception):
    def __init__(self, code, endpoint_id):
        self.captur_code = code
        self.captur_message = f"Endpoint {endpoint_id} not found."

class GoogleCloudVertexAIEndpointImageTooLargeError(Exception):
    def __init__(self, code, size_limit):
        self.captur_code = code
        self.captur_message = f"Image greater than {size_limit}."

class GoogleCloudVertexAIEndpointNoModelDeployedError(Exception):
    def __init__(self, code, endpoint_id):
        self.captur_code = code
        self.captur_message = f"No model is deployed at endpoint {endpoint_id}."

class GoogleCloudVertexAIEndpointCorruptedImageError(Exception):
    def __init__(self, code, message):
        self.captur_code = code
        self.captur_message = message

# ============ Google Cloud Vertex AI General Exceptions ============ #
class GoogleCloudVertexAIModelDoesNotExistError(Exception):
    pass
class GoogleCloudVertexAIDatasetDoesNotExistError(Exception):
    pass
class GoogleCloudVertexAIResourceDoesNotExistError(Exception):
    pass
class GoogleCloudVertexAICompatibilityError(Exception):
    pass

# ============ Sentry Errors ============ #
class SentryDSNNotProvidedError(Exception):
    pass

==> captur-ml-0.2.35.tar.gz: captur-ml-0.2.35/captur_ml_sdk/dtypes/exceptions/__init__.py <==
class CapturMLError(Exception):
    def __init__(self, status, message, source):
        self.status = status
        self.message = message
        self.source = source

    def get_error_callback(self, request_id):
        return {
            "request_id": request_id,
            "status": self.status,
            "message": self.message
        }

# ============ PubSub Exceptions ============ #
class GoogleCloudPubSubTopicDoesNotExistError(Exception):
    pass

# ============ Google Cloud Storage Exceptions ============ #
class GoogleCloudStoragePermissionError(Exception):
    def __init__(self, status, message):
        self.status = status
        self.message = message

    def get_error_callback(self, request_id):
        return {
            "request_id": request_id,
            "status": self.status,
            "message": self.message
        }

    pass
class GoogleCloudStorageResourceNotFoundError(Exception):
    pass
class GoogleCloudStorageBucketNotFoundError(Exception):
    pass

# ============ Google Cloud Vertex AI Endpoint Exceptions ============ #
class GoogleCloudVertexAIEndpointDoesNotExistError(Exception):
    pass
class GoogleCloudVertexAIEndpointImageTooLargeError(Exception):
    pass
class GoogleCloudVertexAIEndpointNoModelDeployedError(Exception):
    pass

# ============ Google Cloud Vertex AI General Exceptions ============ #
class GoogleCloudVertexAIModelDoesNotExistError(Exception):
    pass
class GoogleCloudVertexAIDatasetDoesNotExistError(Exception):
    pass
class GoogleCloudVertexAIResourceDoesNotExistError(Exception):
    pass
class GoogleCloudVertexAICompatibilityError(Exception):
    pass

# ============ Sentry Errors ============ #
class SentryDSNNotProvidedError(Exception):
    pass
